@@ -39,10 +39,8 @@
 #include <QDockWidget>
 #include <QFileDialog>
 #include <QTreeView>
-#include <QPushButton>
 #include <QGridLayout>
 #include <QString>
-#include <QVBoxLayout>
 #include <QMovie>
 #include <QGraphicsScene>
 #include <QGraphicsView>
@@ -55,7 +53,6 @@
 #include <QSvgRenderer>
 
 // include files for KDE
-#include <KIconLoader>
 #include <KMessageBox>
 #include <KLocalizedString>
 #include <KConfig>
